@@ -50,6 +50,7 @@ API arguments and calls
 import abc
 import argparse
 import collections
+import copy
 import enum
 import glob
 import hashlib
@@ -57,6 +58,7 @@ import inspect
 import json
 import logging
 import os
+import pathlib
 import re
 import shlex
 import sys
@@ -64,7 +66,7 @@ import textwrap
 import threading
 from contextlib import closing
 
-from mini_buildd import call, changes, config, dist, events, files, net, package, util, values
+from mini_buildd import call, changes, config, daemon, dist, events, files, net, package, pool, util, values
 
 LOG = logging.getLogger(__name__)
 
@@ -100,6 +102,9 @@ class Argument():
     ============  ============ ============ =========== =================
     """
 
+    HTML_TYPE = None
+    HTML_SYNTAX = None
+
     #: Validate that values are actually of that type
     VALUE_TYPE = str
 
@@ -200,10 +205,13 @@ class Argument():
                 kvsargs["default"] = self._default
         return kvsargs
 
+    def usage(self):
+        return f"{self.identity}: {self.doc}\n\nFormat: {self.HTML_SYNTAX}"
+
 
 class StrArgument(Argument):
     HTML_TYPE = "text"
-    HTML_HELP = "Enter plain string"
+    HTML_SYNTAX = "Plain string"
 
     def argparse_kvsargs(self):
         return {**super().argparse_kvsargs(), **{"action": "store"}}
@@ -211,17 +219,17 @@ class StrArgument(Argument):
 
 class UrlArgument(StrArgument):
     HTML_TYPE = "url"
-    HTML_HELP = "Enter URL string"
+    HTML_SYNTAX = "URL string"
 
 
 class MultilineStrArgument(StrArgument):
     HTML_TYPE = "textarea"
-    HTML_HELP = "Enter multiline string"
+    HTML_SYNTAX = "Multiline string"
 
 
 class ChoiceArgument(Argument):
     HTML_TYPE = "select"
-    HTML_HELP = "Select one choice"
+    HTML_SYNTAX = "Choice"
 
     def value(self):
         value = super().value()
@@ -241,7 +249,7 @@ class ChoiceArgument(Argument):
 class IntArgument(StrArgument):
     VALUE_TYPE = int
     HTML_TYPE = "number"
-    HTML_HELP = "Enter integer number"
+    HTML_SYNTAX = "Integer number"
 
     def argparse_kvsargs(self):
         return {**super().argparse_kvsargs(), **{"type": int}}
@@ -250,7 +258,7 @@ class IntArgument(StrArgument):
 class BoolArgument(ChoiceArgument):
     VALUE_TYPE = bool
     HTML_TYPE = "checkbox"
-    HTML_HELP = "Check box to activate"
+    HTML_SYNTAX = "Checkbox"
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, choices=[True, False], default=False, **kwargs)
@@ -295,7 +303,7 @@ class _ExtendAction(argparse._AppendAction):  # pylint: disable=protected-access
 class ListArgument(StrArgument):
     VALUE_TYPE = list
     SEPARATOR = ","
-    HTML_HELP = "Enter list as comma-separated strings"
+    HTML_SYNTAX = "List as comma-separated strings"
 
     @classmethod
     def s2v(cls, str_value):
@@ -419,6 +427,7 @@ class Call():
     NEEDS_RUNNING_DAEMON = False
     CONFIRM = False
     RESULT_DESC = ""
+    CATEGORY = "Consumer"
 
     @classmethod
     def name(cls):
@@ -429,11 +438,13 @@ class Call():
 
     @classmethod
     def doc(cls):
-        doc = inspect.getdoc(cls)
-        if cls.RESULT_DESC:
-            doc += f"\n\nJSON result description:\n\n{textwrap.indent(cls.RESULT_DESC, '  ')}"
-        doc += f"\n\nAuthorization: {cls.AUTH}"
-        return doc
+        return (
+            f"{inspect.getdoc(cls)}\n"
+            f"{f'\nJSON result description:\n\n{textwrap.indent(cls.RESULT_DESC, "  ")}\n' if cls.RESULT_DESC else ''}"
+            "\n"
+            f"{'This is a MAINTENANCE call: Daemon will be automatically STOPPED while running, any ongoing events will be CANCELED.\n\n' if issubclass(cls, _Maintenance) else ''}"
+            f"Authorization: {cls.AUTH}"
+        )
 
     @classmethod
     def doc_title(cls):
@@ -443,17 +454,6 @@ class Call():
     def doc_body(cls):
         return cls.doc().partition("\n")[2][1:]
 
-    # Category support -- purely for structuring documentation.
-    CATEGORIES = ["Consumer", "Developer", "Administrator"]
-
-    @classmethod
-    def category(cls):
-        if cls.AUTH in [config.AUTH_NONE, config.AUTH_LOGIN]:
-            return cls.CATEGORIES[0]
-        if cls.AUTH in [config.AUTH_STAFF]:
-            return cls.CATEGORIES[1]
-        return cls.CATEGORIES[2]
-
     @classmethod
     def uri(cls):
         return config.URIS["api"]["view"].join(cls.name() + "/")
@@ -593,8 +593,6 @@ MAINTENANCE_LOCK = threading.Lock()
 
 class _Maintenance:
     def run(self):
-        from mini_buildd import daemon
-
         if MAINTENANCE_LOCK.acquire(blocking=False):  # pylint: disable=consider-using-with
             try:
                 with daemon.Stopped():
@@ -605,6 +603,22 @@ class _Maintenance:
             raise util.HTTPUnavailable("Another maintenance API call currently running")
 
 
+#: Category options (mixins). For structuring documentation only (API index).
+class _CatConsumer:
+    CATEGORY = "Consumer"
+
+
+class _CatDeveloper:
+    CATEGORY = "Developer"
+
+
+class _CatAdministrator:
+    CATEGORY = "Administrator"
+
+
+CATEGORIES = [_CatConsumer.CATEGORY, _CatDeveloper.CATEGORY, _CatAdministrator.CATEGORY]
+
+
 #: API calls
 class Status(Call):
     """
@@ -631,10 +645,10 @@ class Status(Call):
     def _run(self):
         self.result = {
             "version": util.__version__,
-            "identity": util.daemon().model.identity,
+            "identity": daemon.get_model().identity,
             "url": util.http_endpoint().geturl(),
-            "incoming_url": util.daemon().model.mbd_get_ftp_endpoint().geturl(),
-            "load": util.daemon().builder.load() if util.daemon().is_alive() else -1.0,
+            "incoming_url": daemon.get_model().mbd_get_ftp_endpoint().geturl(),
+            "load": daemon.get().builder.load() if daemon.get().is_alive() else -1.0,
             "chroots": [c.mbd_key() for c in util.models().Chroot.mbd_get_active()],
             "remotes": [r.mbd_url() for r in util.models().Remote.mbd_get_active_or_auto_reactivate()],
         }
@@ -644,40 +658,60 @@ class Status(Call):
 
 class PubKey(Call):
     """
-    Get public key
+    Get ASCII-armored GnuPG public key of this instance
 
-    Get ASCII-armored GnuPG public key of this instance.
+    Used to sign the APT repositories ('APT key') and for authorization across instances.
 
-    Used to sign the apt repositories (apt key) and for authorization across instances.
+    See ``Customer's  Manual, APT Bootstrap`` for ways to employ the APT key on yor local system.
     """
 
     def _run(self):
-        self.result = util.daemon().gnupg.pub_key
+        self.result = daemon.get().gnupg.pub_key
 
 
 class DputConf(Call):
     """
     Get recommended dput config snippet
 
-    Usually, this is for integration in your personal ``~/.dput.cf``.
+    Usually, this is for integration in your personal ``~/.dput.cf`` (which will work
+    for both, ``dput`` and ``dput-ng``).
+
+    Administrators may add custom site targets via ``~mini-buildd/etc/dput.cf``.
     """
 
     @classmethod
     def iarguments(cls):
-        yield BoolArgument(["--dput-ng-profile", "-N"], doc="Output dput-ng (json) profile (instead of traditional dput.cf config snippet)")
+        yield BoolArgument(["--without-global"], doc="Exclude recommended global config")
+        yield BoolArgument(["--dput-ng-profile", "-N"], doc="Output dput-ng (json) profile (instead of traditional dput.cf config snippet) only")
 
     def _run(self):
-        if self.args["dput_ng_profile"].value():
-            self.result = util.daemon().model.mbd_get_dputng_profile()
-        else:
-            self.result = util.daemon().model.mbd_get_dput_conf()
+        self.result = ""  # Make sure result is ``str``
 
-            # Optionally add local custom config
-            try:
-                with util.fopen(config.ROUTES["etc"].path.join("dput.cf")) as extra_conf:
-                    self.result += extra_conf.read()
-            except FileNotFoundError:
-                pass
+        if self.args["dput_ng_profile"].value():
+            self.result = daemon.get_model().mbd_get_dputng_profile()
+        else:
+            if not self.args["without_global"].value():
+                self.result = (
+                    "# Recommended global config\n"
+                    "[DEFAULT]\n"
+                    "# Avoid accidental uploads to default target (like 'ftp-master' for Debian)\n"
+                    "default_host_main = _please_specify_target_explicitly_\n"
+                    "\n"
+                )
+
+            self.result += (
+                "# This instance's native target\n"
+                f"{daemon.get_model().mbd_get_dput_conf()}"
+                "\n"
+            )
+
+            site_config_path = config.ROUTES["etc"].path.join("dput.cf")
+            if os.path.exists(site_config_path):
+                with util.fopen(site_config_path) as site_config:
+                    self.result += (
+                        "# Custom site targets\n"
+                        f"{site_config.read()}"
+                    )
 
 
 class SourcesList(Call):
@@ -754,6 +788,64 @@ class Show(Ls):
             value.enrich()
 
 
+class Search(Call):
+    """
+    Search for source or binary package names in ``repositories``, ``builds`` and ``events``
+
+    Be cautious with binary package files found outside of ``repositories``:
+
+    * Matches only found in ``builds`` usually failed installation as some criteria is not met.
+    * Matches found in ``events`` originate from the initial (non source-only) user upload (and thus are local builds).
+    """
+
+    @classmethod
+    def iarguments(cls):
+        yield StrArgument(["pattern"],
+                          doc=(
+                              "Pattern for binary or source package name.\n"
+                              "\n"
+                              "Value is a glob pattern; '*' is added automatically to begin and end of the pattern."
+                          ))
+
+    EMPTY_RESULT = {
+        "repositories": [],
+        "builds": [],
+        "events": [],
+    }
+
+    MSG = {
+        "repositories": "In repository, safe to use",
+        "builds": "Binary packages maybe not installed/some criteria not met",
+        "events": "Be cautious: Binary package originates from user upload (local build)",
+    }
+
+    def _run(self):
+        self.result = {}
+
+        pattern = "*" + self.args["pattern"].value() + "*"
+
+        # Search in repositories
+        repositories_route = config.ROUTES["repositories"]
+        for repository in util.models().Repository.objects.all():
+            for src, file_name in repository.mbd_reprepro.pool.isearch(pattern):
+                self.result.setdefault(src, copy.deepcopy(self.EMPTY_RESULT))
+                self.result[src]["repositories"].append(str(file_name.relative_to(repositories_route.path.full)))
+
+        # Search in builds
+        builds_route = config.ROUTES["builds"]
+        builds_path = pool.Dir(pathlib.Path(builds_route.path.full), pooldir="", sources_glob="*")
+        for src, file_name in builds_path.isearch(pattern):
+            self.result.setdefault(src, copy.deepcopy(self.EMPTY_RESULT))
+            self.result[src]["builds"].append(str(file_name.relative_to(builds_route.path.full)))
+
+        # Search in events
+        events_route = config.ROUTES["events"]
+        events_path = pool.Dir(pathlib.Path(events_route.path.full), pooldir="", sources_glob="*")
+        for src, file_name in events_path.isearch(pattern):
+            self.result.setdefault(src, copy.deepcopy(self.EMPTY_RESULT))
+            self.result[src]["events"].append(str(file_name.relative_to(events_route.path.full)))
+
+
 MULT_VERSIONS_PER_DIST_NOTE = "Use as safeguard, or for rare cases of multiple version of the same package in one distribution (in different components)"
 
 
@@ -772,12 +864,12 @@ class Debdiff(Call):
     def _run(self):
         repository = self.args["repository"].object()
         repositories_path = config.ROUTES["repositories"].path
-        dsca = repository.mbd_dsc_pool_path(self.args["source"].value(), self.args["versiona"].value())
-        dscb = repository.mbd_dsc_pool_path(self.args["source"].value(), self.args["versionb"].value())
+        dsca = repository.mbd_reprepro.pool.dsc_path(self.args["source"].value(), self.args["versiona"].value())
+        dscb = repository.mbd_reprepro.pool.dsc_path(self.args["source"].value(), self.args["versionb"].value())
         self.result = call.Call(["debdiff", repositories_path.join(dsca), repositories_path.join(dscb)]).stdout
 
 
-class Migrate(_Staff, _Confirm, Call):
+class Migrate(_Staff, _Confirm, _CatDeveloper, Call):
     """
     Migrate source package
 
@@ -804,7 +896,7 @@ class Migrate(_Staff, _Confirm, Call):
                                        version=version if version else None)
 
 
-class Remove(_Admin, _Confirm, Call):
+class Remove(_Admin, _Confirm, _CatAdministrator, Call):
     """
     Remove source package
 
@@ -829,7 +921,7 @@ class Remove(_Admin, _Confirm, Call):
                                       without_rollback=self.args["without_rollback"].value())
 
 
-class Port(_Staff, _Running, _Confirm, Call):
+class Port(_Staff, _Running, _Confirm, _CatDeveloper, Call):
     """
     Port internal source package
 
@@ -850,7 +942,7 @@ class Port(_Staff, _Running, _Confirm, Call):
     def _run(self):
         self.result = []
         version = self.args["version"].value()
-        for to_diststr in self.args["to_distributions"].value():
+        for to_diststr in set(self.args["to_distributions"].value()):
             self.result.append(package.port(self.args["source"].value(),
                                             self.args["from_distribution"].value(),
                                             to_diststr,
@@ -858,7 +950,7 @@ class Port(_Staff, _Running, _Confirm, Call):
                                             options=self.args["options"].value().split("|")))
 
 
-class PortExt(_Staff, _Running, _Confirm, Call):
+class PortExt(_Staff, _Running, _Confirm, _CatDeveloper, Call):
     """
     Port external source package
 
@@ -875,14 +967,14 @@ class PortExt(_Staff, _Running, _Confirm, Call):
 
     def _run(self):
         self.result = []
-        for diststr in self.args["distributions"].value():
+        for diststr in set(self.args["distributions"].value()):
             self.result.append(package.port_ext(self.args["dsc"].value(),
                                                 diststr,
                                                 options=self.args["options"].value().split("|"),
                                                 allow_unauthenticated=self.args["allow_unauthenticated"].value()))
 
 
-class Retry(_Staff, _Running, _Confirm, Call):
+class Retry(_Staff, _Running, _Confirm, _CatDeveloper, Call):
     """
     Retry a previously failed source package
     """
@@ -919,11 +1011,11 @@ class Retry(_Staff, _Running, _Confirm, Call):
         LOG.debug("Retry: Found solitaire changes file: %s", changes_filename)
 
         # Should be save now to re-upload the changes files found in path
-        changes.Base(changes_filename).upload(util.daemon().model.mbd_get_ftp_endpoint(), force=True)
+        changes.Base(changes_filename).upload(daemon.get_model().mbd_get_ftp_endpoint(), force=True)
         self.result = os.path.basename(changes_filename)
 
 
-class Cancel(_Staff, _Running, _Confirm, Call):
+class Cancel(_Staff, _Running, _Confirm, _CatDeveloper, Call):
     """Cancel an ongoing package build"""
 
     @classmethod
@@ -931,19 +1023,15 @@ class Cancel(_Staff, _Running, _Confirm, Call):
         yield StrArgument(["bkey"], choices=values.current_builds, doc="Build key (``<source>/<version>/<timecode>/<arch>`` of ongoing builds; see ``extra.bkey`` in BUILDING events)")
 
     def _run(self):
-        util.daemon().builder.cancel(self.args["bkey"].value(), f"{self.request.user}")
+        daemon.get().builder.cancel(self.args["bkey"].value(), f"{self.request.user}")
         self.result = self.args["bkey"].value()
 
 
-class SetUserKey(_Login, _Confirm, Call):
+class SetUserKey(_Login, _Confirm, _CatDeveloper, Call):
     """
     Set a user's GnuPG public key
     """
 
-    @classmethod
-    def category(cls):
-        return cls.CATEGORIES[1]
-
     @classmethod
     def iarguments(cls):
         yield MultilineStrArgument(["key"], doc="GnuPG public key; multiline inputs will be handled as ascii armored full key, one-liners as key ids")
@@ -1007,13 +1095,11 @@ class Unsubscribe(Subscribe):
                 self.result.append({"source": s.package, "distribution": s.distribution})
 
 
-class RemakeChroots(_Admin, _Confirm, _Maintenance, Call):
+class RemakeChroots(_Admin, _Confirm, _Maintenance, _CatAdministrator, Call):
     """
     Remake chroots
 
     Run actions 'remove', 'prepare', 'check' and 'activate'.
-
-    Note that Daemon will be stopped before running, cancelling ongoing events (``BUILDING``, ``PACKAGING``).
     """
 
     @classmethod
@@ -1034,7 +1120,31 @@ class RemakeChroots(_Admin, _Confirm, _Maintenance, Call):
                 self.result[key] = f"Failed: {util.e2http(e)}"
 
 
-class Start(_Admin, _Confirm, Call):
+class Reindex(_Admin, _Confirm, _Maintenance, _CatAdministrator, Call):
+    """
+    Force repository reindex
+
+    Usually, you reindex by doing an explicit ``check`` on a Repository
+    instance -- however, that method would not reindex in case the
+    repository config is unchanged. Use this call if you feel you need it
+    anyway for whatever reason.
+
+    If you just upgraded from 2.2.x, it's recommended to run it once
+    (2.4.x reindex additionally runs ``repreprop flood``, which may make
+    some arch=all packages available for (subsequently) added
+    architectures).
+    """
+
+    @classmethod
+    def iarguments(cls):
+        yield Repositories(["--repositories", "-R"], default=values.all_repositories)
+
+    def _run(self):
+        for r in self.args["repositories"].objects():
+            r.mbd_reprepro_update_config(force_reindex=True)
+
+
+class Start(_Admin, _Confirm, _CatAdministrator, Call):
     """
     Start Daemon (accept incoming)
 
@@ -1042,23 +1152,23 @@ class Start(_Admin, _Confirm, Call):
     """
 
     def _run(self):
-        util.daemon().mbd_start()
+        daemon.start()
 
 
-class Stop(_Admin, _Confirm, Call):
+class Stop(_Admin, _Confirm, _CatAdministrator, Call):
     """
     Stop Daemon (stop accepting incoming)
 
-    Does nothing if already stopped. Any possibly running builds will be cancelled.
+    Does nothing if already stopped. Any ongoing events will be CANCELED.
 
     This state is *not persisted*. Please *deactivate* the Daemon instance via :mbdpage:`setup` to persist over *mini-buildd service* restarts.
     """
 
     def _run(self):
-        util.daemon().mbd_stop()
+        daemon.stop()
 
 
-class Wake(_Staff, _Confirm, Call):
+class Wake(_Staff, _Confirm, _CatDeveloper, Call):
     """
     Wake a remote instance
     """
@@ -1074,17 +1184,13 @@ class Wake(_Staff, _Confirm, Call):
         self.result = remote.mbd_get_status(wake=True, wake_sleep=self.args["sleep"].value(), wake_attempts=self.args["attempts"].value())
 
 
-class Handshake(Call):
+class Handshake(_CatAdministrator, Call):
     """
     Check if signed message matches a remote, reply our signed message on success
 
     This is for internal use only.
     """
 
-    @classmethod
-    def category(cls):
-        return cls.CATEGORIES[2]
-
     @classmethod
     def iarguments(cls):
         yield MultilineStrArgument(["--signed-message", "-S"])
@@ -1094,7 +1200,7 @@ class Handshake(Call):
         for r in util.models().Remote.objects.all():
             try:
                 r.mbd_verify(signed_message)
-                self.result = util.daemon().handshake_message()
+                self.result = daemon.get().handshake_message()
                 LOG.debug("Remote handshake ok: '%s': %s: %s", r, r.key_long_id, r.key_name)
                 return
             except Exception as e:
@@ -1102,7 +1208,7 @@ class Handshake(Call):
         raise util.HTTPBadRequest(f"GnuPG handshake failed: No remote for public key on {util.http_endpoint()}")
 
 
-class Cronjob(_Admin, _Confirm, Call):
+class Cronjob(_Admin, _Confirm, _CatAdministrator, Call):
     """
     Run a cron job now (out of schedule)
     """
@@ -1112,11 +1218,11 @@ class Cronjob(_Admin, _Confirm, Call):
         yield StrArgument(["id"], choices=values.all_cronjobs)
 
     def _run(self):
-        job = util.daemon().crontab.get(self.args["id"].value())
+        job = daemon.get().crontab.get(self.args["id"].value())
         self.result[job.id()] = job.run()
 
 
-class Uploaders(_Admin, _Running, Call):
+class Uploaders(_Admin, _Running, _CatAdministrator, Call):
     """
     Get upload permissions for repositories
     """
@@ -1126,8 +1232,6 @@ class Uploaders(_Admin, _Running, Call):
         yield Repositories(["--repositories", "-R"], default=values.all_repositories)
 
     def _run(self):
-        from mini_buildd import daemon
-
         for r in self.args["repositories"].objects():
             self.result[r.identity] = {"allow_unauthenticated_uploads": r.allow_unauthenticated_uploads}
             with closing(daemon.UploadersKeyring(r.identity)) as gpg:
@@ -1148,7 +1252,7 @@ class SnapshotLs(_Running, Call):
         self.result = diststr2repository(diststr).mbd_reprepro.get_snapshots(diststr)
 
 
-class SnapshotCreate(_Admin, _Confirm, SnapshotLs):
+class SnapshotCreate(_Admin, _Confirm, _CatAdministrator, SnapshotLs):
     """
     Create a repository snapshot
     """
@@ -1173,7 +1277,7 @@ class SnapshotDelete(SnapshotCreate):
         diststr2repository(diststr).mbd_reprepro.del_snapshot(diststr, self.args["name"].value())
 
 
-class Debmirror(_Admin, _Confirm, Call):
+class Debmirror(_Admin, _Confirm, _CatAdministrator, Call):
     """
     Make local partial repository mirror via :debpkg:`debmirror`
 
@@ -1240,7 +1344,7 @@ class Debmirror(_Admin, _Confirm, Call):
             call.Call(debmirror).check()
 
 
-class KeyringPackages(_Admin, _Running, _Confirm, Call):
+class KeyringPackages(_Admin, _Running, _Confirm, _CatAdministrator, Call):
     """
     Build keyring packages
     """
@@ -1252,7 +1356,7 @@ class KeyringPackages(_Admin, _Running, _Confirm, Call):
 
     def _run(self):
         self.result = []
-        events_queue = events.Attach(util.daemon().events)
+        events_queue = events.Attach(daemon.get().events)
 
         for diststr in self.args["distributions"].value():
             repository, distribution, suite = util.models().parse_diststr(diststr)
@@ -1274,7 +1378,7 @@ class KeyringPackages(_Admin, _Running, _Confirm, Call):
                         repository.mbd_package_migrate(upload["source"], distribution, suite, full=True, version=upload["version"])
 
 
-class TestPackages(_Admin, _Running, _Confirm, Call):
+class TestPackages(_Admin, _Running, _Confirm, _CatAdministrator, Call):
     """
     Build test packages
     """
@@ -1290,7 +1394,7 @@ class TestPackages(_Admin, _Running, _Confirm, Call):
 
     def _run(self):
         self.result = []
-        events_queue = events.Attach(util.daemon().events)
+        events_queue = events.Attach(daemon.get().events)
 
         for source in self.args["sources"].value():
             for diststr in self.args["distributions"].value():
@@ -1311,11 +1415,9 @@ class TestPackages(_Admin, _Running, _Confirm, Call):
                         LOG.debug("Test package result: %s", event)
 
 
-class Setup(_Admin, _Confirm, _Maintenance, Call):
+class Setup(_Admin, _Confirm, _Maintenance, _CatAdministrator, Call):
     """
     Create, update or inspect your setup
-
-    Note that Daemon will be stopped before running, cancelling ongoing events (``BUILDING``, ``PACKAGING``).
     """
 
     @classmethod
@@ -1568,7 +1670,7 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
     @classmethod
     def ilocal_archive_urls(cls):
         try:
-            import aptsources.sourceslist
+            import aptsources.sourceslist  # pylint: disable=import-outside-toplevel
             for src in (src for src in aptsources.sourceslist.SourcesList() if not src.invalid and not src.disabled):
                 # These URLs come from the user. 'normalize' the uri first to have exactly one trailing slash.
                 yield src.uri.rstrip("/") + "/"
@@ -1904,8 +2006,8 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
             chroots.merge(Setup.Dists([c.mbd_key()]))
 
         return Setup(
-            identity=util.daemon().model.identity,
-            ftp_endpoint=util.daemon().model.ftpd_bind,
+            identity=daemon.get_model().identity,
+            ftp_endpoint=daemon.get_model().ftpd_bind,
             archives=[a.url for a in util.models().Archive.objects.all()],
             sources=[d.base_source.codename for d in util.models().Distribution.objects.all()],
             distributions=[d.mbd_setup() for d in util.models().Distribution.objects.all()],
@@ -1917,8 +2019,8 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
     @classmethod
     def setup_extend(cls):
         return Setup(
-            identity=util.daemon().model.identity,
-            ftp_endpoint=util.daemon().model.ftpd_bind,
+            identity=daemon.get_model().identity,
+            ftp_endpoint=daemon.get_model().ftpd_bind,
             archives_from_origins=True,
             sources_from_origins=True,
             distributions_from_sources=True,
