@@ -45,7 +45,7 @@ class StdErrHandler(logging.StreamHandler):
     }
 
     #: Generic log format
-    LOG_FORMAT = "{systemd_prefix}{levelname[0]}: {message} [{name}({filename}:{lineno})]"
+    LOG_FORMAT = "{systemd_prefix}{levelname[0]}: {message} [{threadName}({thread}), {name}({filename}:{lineno})]"
 
     def __init__(self):
         super().__init__(stream=sys.stderr)
