@@ -13,7 +13,6 @@ import enum
 import functools
 import logging
 import re
-import shlex
 
 import debian.debian_support
 import distro_info
@@ -95,24 +94,6 @@ DISTRO_INFO = {
     "Ubuntu": UbuntuDistroInfo(),
 }
 
-#: Convenience component sorting to get some well known components sorted as we are used to
-COMPONENTS_SORT_KEYS = {
-    # Debian
-    "main": "0",
-    "contrib": "1",
-    "non-free": "2",
-    "non-free-firmware": "3",
-    # Ubuntu (also uses 'main')
-    "universe": "4",
-    "restricted": "5",
-    "multiverse": "6",
-}
-
-
-def sorted_components(components):
-    return sorted(components, key=lambda c: COMPONENTS_SORT_KEYS.get(c, c))
-
-
 APT_KEYS = {
     "Debian": {
         "bookworm": {
@@ -198,23 +179,34 @@ SUITE_SETUP = {
 }
 
 SETUP = {
-    #: Default (Debian bullseye and up, Ubuntu groovy and up) lintian options. Overwrite in codename sections if needed.
-    "lintian_options": {
-        "common": ["--suppress-tags", "bad-distribution-in-changes-file"],
-        #: Lintian "warnfail" option history:
-        #:  * Debian (stretch)  2.5.50: Deprecates '--fail-on-warnings'.
-        #:  * Debian (bullseye) 2.16.0: Drops support for '--fail-on-warnings' (NO WAY TO DO "WARNFAIL").
-        #:  * Debian (bullseye) 2.77.0: Introduces '--fail-on'.
-        #:  * Ubuntu (focal)    2.62.0: Release that does not have either (NO WAY TO DO "WARNFAIL").
-        #:  * Ubuntu (groovy)   2.89.0: 1st release >= 2.77.
-        #: Conclusion:
-        #:  * Debian >=bullseye needs '--fail-on error,warning', below needs '--fail-on-warnings'.
-        #:  * Ubuntu >=groovy needs '--fail-on error,warning', below needs '--fail-on-warnings'.
-        #:  * Ubuntu focal just can't do it.
-        "warnfail": ["--fail-on", "error,warning"],
+    "defaults": {  # Plain default values for model fields
+        "distribution": {
+            "sbuild_config_blocks": "set-default-path ccache",
+            "sbuild_setup_blocks": "apt-setup apt-update ccache eatmydata",
+            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file,bogus-mail-host,bogus-mail-host-in-debian-changelog",
+            "lintian_warnfail_options": "--fail-on error,warning",
+        },
     },
-
-    "origin": {
+    "layout": {  # Layout Default
+        "Default": {
+            "suites": SUITE_SETUP,
+            "rollback": {"stable": 6, "hotfix": 4, "testing": 3, "unstable": 9, "snapshot": 12, "experimental": 6},
+        },
+        "Default (no rollbacks)": {
+            "suites": SUITE_SETUP,
+            "rollback": {},
+        },
+        "Debian Developer": {
+            "suites": {s: c for s, c in SUITE_SETUP.items() if s in ["stable", "testing", "unstable", "experimental"]},
+            "rollback": {},
+            "options": {
+                "mandatory_version_regex": ".*",
+                "experimental_mandatory_version_regex": ".*",
+                "meta_distributions": {"unstable": "sid-unstable", "experimental": "sid-experimental"},
+            },
+        },
+    },
+    "origin": {  # Custom setup for actual distributons
         "Debian": {
             #: "Usually used" paths on a mirror. Can be used to guess individual archive URLS from a base mirror URL.
             "archive_paths": ["debian", "debian-security", "debian-ports", "debian-archive/debian", "debian-archive/debian-security", "debian-archive/debian-backports"],
@@ -256,6 +248,7 @@ SETUP = {
                     ],
                 },
                 "bookworm": {
+                    "lintian_version": "2.116.3",
                     "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"], APT_KEYS["Debian"]["bookworm"]["release"]],
                     "extra_sources": [
                         {
@@ -279,6 +272,7 @@ SETUP = {
                     ],
                 },
                 "bullseye": {
+                    "lintian_version": "2.104.0",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"], APT_KEYS["Debian"]["bullseye"]["release"]],
                     "extra_sources": [
@@ -303,6 +297,7 @@ SETUP = {
                     ],
                 },
                 "buster": {
+                    "lintian_version": "2.15.0",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["buster"]["release"], APT_KEYS["Debian"]["bullseye"]["archive"]],
                     "extra_sources": [
@@ -329,11 +324,15 @@ SETUP = {
                             "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"], APT_KEYS["Debian"]["bookworm"]["archive"]],
                         },
                     ],
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
+                    "distribution": {
+                        "options": {
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
+                        },
                     },
                 },
                 "stretch": {
+                    "lintian_version": "2.5.50.4",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["stretch"]["archive"], APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"], APT_KEYS["Debian"]["stretch"]["release"]],
                     "extra_sources": [
@@ -360,11 +359,15 @@ SETUP = {
                             "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"]],
                         },
                     ],
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
+                    "distribution": {
+                        "options": {
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
+                        },
                     },
                 },
                 "jessie": {
+                    "lintian_version": "2.5.30+deb8u4",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["wheezy"]["archive"], APT_KEYS["Debian"]["jessie"]["release"], APT_KEYS["Debian"]["jessie"]["archive"]],
                     "extra_sources": [
@@ -404,13 +407,13 @@ SETUP = {
                             # * jessie from ftp.debian.org (was left there for LTS for 'amd64 armel armhf i386' only) would work w/o that flag, as it is signed differently.
                             # However, both archives will match the jessie source, and both could potentially be used.
                             "sbuild_setup_blocks": "apt-allow-unauthenticated apt-setup apt-key-binary apt-update ccache eatmydata",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
                 "wheezy": {
+                    "lintian_version": "2.5.10.4",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["wheezy"]["archive"], APT_KEYS["Debian"]["wheezy"]["release"], APT_KEYS["Debian"]["jessie"]["archive"]],
                     "extra_sources": [
@@ -441,6 +444,8 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "sbuild_setup_blocks": "apt-allow-unauthenticated apt-setup apt-key-binary apt-update ccache eatmydata",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
                     "chroot": {
@@ -448,13 +453,11 @@ SETUP = {
                             "debootstrap_extra_options": "--include=realpath",
                         },
                     },
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
                 "squeeze": {
                     "broken": "Only works with sbuild < 0.84",
 
+                    "lintian_version": "2.4.3+squeeze1",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["squeeze"]["archive"], APT_KEYS["Debian"]["squeeze"]["release"]],
                     "extra_sources": [
@@ -485,6 +488,8 @@ SETUP = {
                         "options": {
                             "build_dep_resolver": 0,  # util.models().Distribution.RESOLVER_APT
                             "sbuild_setup_blocks": "apt-no-check-valid-until apt-allow-unauthenticated apt-setup apt-key-add apt-update ccache eatmydata",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
                     "chroot": {
@@ -492,13 +497,11 @@ SETUP = {
                             "debootstrap_extra_options": "--include=realpath",
                         },
                     },
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
                 "lenny": {
                     "broken": "Cannot build test packages (only dh7 available)",
 
+                    "lintian_version": "1.24.2.1+lenny1",
                     "components": ["main", "contrib", "non-free"],
                     "apt_keys": [APT_KEYS["Debian"]["squeeze"]["archive"], APT_KEYS["Debian"]["lenny"]["release"]],
                     "extra_sources": [
@@ -524,6 +527,8 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "sbuild_setup_blocks": "apt-no-check-valid-until apt-allow-unauthenticated apt-setup apt-key-add apt-update ccache eatmydata",
+                            "lintian_extra_options": "--info",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
                     "chroot": {
@@ -532,10 +537,6 @@ SETUP = {
                             "debootstrap_extra_options": "--include=realpath,timeout",
                         },
                     },
-                    "lintian_options": {
-                        "common": [],
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
             },
         },
@@ -615,6 +616,7 @@ SETUP = {
                     },
                 },
                 "noble": {  # noble: 24.04 LTS 2029
+                    "lintian_version": "2.117.0ubuntu1",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -645,6 +647,7 @@ SETUP = {
                     },
                 },
                 "mantic": {  # mantic: 23.10
+                    "lintian_version": "2.116.3ubuntu3",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -675,6 +678,7 @@ SETUP = {
                     },
                 },
                 "lunar": {  # lunar: 23.04
+                    "lintian_version": "2.116.3ubuntu1",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -705,6 +709,7 @@ SETUP = {
                     },
                 },
                 "kinetic": {  # kinetic: 22.10
+                    "lintian_version": "2.115.3ubuntu2",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -735,6 +740,7 @@ SETUP = {
                     },
                 },
                 "jammy": {  # jammy: 22.04 LTS 2027
+                    "lintian_version": "2.114.0ubuntu1",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -765,6 +771,7 @@ SETUP = {
                     },
                 },
                 "impish": {  # impish: 21.10
+                    "lintian_version": "2.104.0ubuntu3",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -795,6 +802,7 @@ SETUP = {
                     },
                 },
                 "hirsute": {  # hirsute: 21.04
+                    "lintian_version": "2.104.0ubuntu1",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -820,11 +828,13 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "deb_build_options": "noddebs",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
                         },
                         "arch_optional": ["i386"],
                     },
                 },
                 "groovy": {  # groovy: 20.10
+                    "lintian_version": "2.89.0",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -850,11 +860,13 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "deb_build_options": "noddebs",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
                         },
                         "arch_optional": ["i386"],
                     },
                 },
                 "focal": {  # focal: 20.04 LTS 2025 ESM 2030
+                    "lintian_version": "2.62.0",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2012"], APT_KEYS["Ubuntu"]["2018"]],
                     "extra_sources": [
                         {
@@ -880,6 +892,7 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "deb_build_options": "noddebs",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
                         },
                         # Ubuntu drops i386 (starting with focal)
                         # 'focal' still has i386 repo (debootrap still works), so i386 is still picked
@@ -890,12 +903,11 @@ SETUP = {
                         # is to make this arch optional.
                         # Ref: https://discourse.ubuntu.com/t/community-process-for-32-bit-compatibility/12598?u=d0od
                         "arch_optional": ["i386"],
-                    },
-                    "lintian_options": {
-                        "warnfail": [],
+                        "lintian_warnfail_options": "",
                     },
                 },
                 "bionic": {  # bionic: 18.04 LTS 2023 ESM 2028
+                    "lintian_version": "2.5.81ubuntu1",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2012"]],
                     "extra_sources": [
                         {
@@ -923,13 +935,13 @@ SETUP = {
                             # Starting with cosmic (18.10), Ubuntu uses 'ddeb' as file appendix for automated debug packages.
                             # reprepro can't handle these yet -- so this is needed for a workaround.
                             "deb_build_options": "noddebs",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
                 "xenial": {  # xenial: 16.04 LTS 2021 ESM 2026
+                    "lintian_version": "2.5.43",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2004"], APT_KEYS["Ubuntu"]["2012"]],
                     "extra_sources": [
                         {
@@ -955,15 +967,15 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "sbuild_setup_blocks": "apt-setup apt-key-add apt-update ccache eatmydata",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
                 "trusty": {  # trusty: 14.04 LTS 2019 ESM 2024
                     "broken": "``upstart`` install fails in build chroots",
 
+                    "lintian_version": "2.5.22ubuntu1",
                     "apt_keys": [APT_KEYS["Ubuntu"]["2004"], APT_KEYS["Ubuntu"]["2012"]],
                     "extra_sources": [
                         {
@@ -989,6 +1001,8 @@ SETUP = {
                     "distribution": {
                         "options": {
                             "sbuild_setup_blocks": "apt-setup apt-key-add apt-update ccache eatmydata",
+                            "lintian_extra_options": "--info --suppress-tags bad-distribution-in-changes-file",
+                            "lintian_warnfail_options": "--fail-on-warnings",
                         },
                     },
                     "chroot": {
@@ -996,9 +1010,6 @@ SETUP = {
                             "debootstrap_extra_options": "--include=realpath",
                         },
                     },
-                    "lintian_options": {
-                        "warnfail": ["--fail-on-warnings"],
-                    },
                 },
             },
         },
@@ -1027,25 +1038,6 @@ SETUP = {
             },
         },
     },
-    "layout": {
-        "Default": {
-            "suites": SUITE_SETUP,
-            "rollback": {"stable": 6, "hotfix": 4, "testing": 3, "unstable": 9, "snapshot": 12, "experimental": 6},
-        },
-        "Default (no rollbacks)": {
-            "suites": SUITE_SETUP,
-            "rollback": {},
-        },
-        "Debian Developer": {
-            "suites": {s: c for s, c in SUITE_SETUP.items() if s in ["stable", "testing", "unstable", "experimental"]},
-            "rollback": {},
-            "options": {
-                "mandatory_version_regex": ".*",
-                "experimental_mandatory_version_regex": ".*",
-                "meta_distributions": {"unstable": "sid-unstable", "experimental": "sid-experimental"},
-            },
-        },
-    },
 }
 
 
@@ -1242,12 +1234,6 @@ class Codename():
             }
         return {}
 
-    def setup_lintian_options(self, kind):
-        """
-        Get lintian options from SETUP
-        """
-        return util.mdget(self.setup, ["lintian_options", kind], SETUP["lintian_options"][kind])
-
     def setup_extra_sources(self):
         return self.setup.get("extra_sources", [])
 
@@ -1350,13 +1336,6 @@ class SbuildCheck():
             self.mode in [self.Mode.DISABLED, self.Mode.IGNORE] or \
             (status in self.STATUSES_WARN and self.mode is not self.Mode.WARNFAIL)
 
-    def lintian_options(self, codename):
-        _codename = Codename(codename)
-        options = _codename.setup_lintian_options("common")
-        if self.mode == self.Mode.WARNFAIL:
-            options += _codename.setup_lintian_options("warnfail")
-        return shlex.join(options)
-
 
 class Dist():
     """
