@@ -11,7 +11,7 @@ import debian.changelog
 import debian.deb822
 import debian.debian_support
 
-from mini_buildd import call, changes, config, files, util
+from mini_buildd import call, changes, config, daemon, files, util
 
 LOG = logging.getLogger(__name__)
 
@@ -185,9 +185,9 @@ class TemplatePackage(util.TmpDir):
     def call(cls, *args, **kwargs):
         environment = call.taint_env(
             {
-                "DEBEMAIL": util.daemon().model.email_address,
-                "DEBFULLNAME": util.daemon().model.mbd_fullname(),
-                "GNUPGHOME": util.daemon().gnupg.home,
+                "DEBEMAIL": daemon.get_model().email_address,
+                "DEBFULLNAME": daemon.get_model().mbd_fullname(),
+                "GNUPGHOME": daemon.get().gnupg.home,
             })
         return call.Call(*args, **kwargs, env=environment)
 
@@ -196,10 +196,10 @@ class KeyringPackage(TemplatePackage):
     def __init__(self):
         super().__init__("archive-keyring")
 
-        self.key_id = util.daemon().gnupg.get_first_sec_key()
+        self.key_id = daemon.get().gnupg.get_first_sec_key()
         LOG.debug("KeyringPackage using key: '%s'", self.key_id)
 
-        self.package_name = f"{util.daemon().model.identity}-archive-keyring"
+        self.package_name = f"{daemon.get_model().identity}-archive-keyring"
 
         # Replace %ID%, %MAINT% and %KEY_ID% in all files in package dir.
         for root, _dirs, _files in os.walk(self.package_dir):
@@ -208,13 +208,13 @@ class KeyringPackage(TemplatePackage):
                 new_file = old_file + ".new"
                 with util.fopen(old_file, "r") as of, util.fopen(new_file, "w") as nf:
                     nf.write(util.subst_placeholders(of.read(),
-                                                     {"ID": util.daemon().model.identity,
+                                                     {"ID": daemon.get_model().identity,
                                                       "KEY_ID": self.key_id,
-                                                      "MAINT": f"{util.daemon().model.mbd_fullname()} <{util.daemon().model.email_address}>"}))
+                                                      "MAINT": f"{daemon.get_model().mbd_fullname()} <{daemon.get_model().email_address}>"}))
                 os.rename(new_file, old_file)
 
         # Export public GnuPG key into the package
-        util.daemon().gnupg.export(os.path.join(self.package_dir, self.package_name + ".gpg"), identity=self.key_id)
+        daemon.get().gnupg.export(os.path.join(self.package_dir, self.package_name + ".gpg"), identity=self.key_id)
 
         # Generate sources.lists
         for r in util.models().Repository.objects.all():
@@ -230,8 +230,8 @@ class KeyringPackage(TemplatePackage):
                                 f.write(apt_line.get(type_) + "\n")
 
         # Generate dput-ng profile
-        with util.fopen(os.path.join(self.package_dir, f"{util.daemon().model.mbd_dput_name()}.json"), "w") as f:
-            f.write(util.json_pretty(util.daemon().model.mbd_get_dputng_profile()))
+        with util.fopen(os.path.join(self.package_dir, f"{daemon.get_model().mbd_dput_name()}.json"), "w") as f:
+            f.write(util.json_pretty(daemon.get_model().mbd_get_dputng_profile()))
 
         # Generate SSL certificate
         certs_dir = os.path.join(self.package_dir, "certs")
@@ -245,7 +245,7 @@ class KeyringPackage(TemplatePackage):
                    "--create",
                    "--package", self.package_name,
                    "--newversion", self.package_version,
-                   f"Automatic keyring package for archive '{util.daemon().model.identity}'."],
+                   f"Automatic keyring package for archive '{daemon.get_model().identity}'."],
                   cwd=self.package_dir).check()
 
         self.call(["dpkg-source",
@@ -308,7 +308,7 @@ def _port(dsc_url, source, diststr, version, comments=None, options=None, allow_
 
         # Get version and author from original changelog; use the first block not
         with util.fopen(os.path.join(dst_path, "debian", "changelog"), "r") as cl:
-            original_author, original_version = Changelog(cl, max_blocks=100).find_first_not(util.daemon().model.email_address)
+            original_author, original_version = Changelog(cl, max_blocks=100).find_first_not(daemon.get_model().email_address)
         LOG.debug("Port: Found original version/author: %s/%s", original_version, original_author)
 
         # Change changelog in DST
@@ -330,7 +330,7 @@ def _port(dsc_url, source, diststr, version, comments=None, options=None, allow_
         # Repack DST
         TemplatePackage.call(["dpkg-source", "-b", dst], cwd=tmpdir).check()
         dsc = os.path.join(tmpdir, dfn.dsc())
-        util.daemon().gnupg.sign(dsc)
+        daemon.get().gnupg.sign(dsc)
 
         # Generate Changes file
         changes_file_path = os.path.join(tmpdir, dfn.changes("source"))
@@ -345,8 +345,8 @@ def _port(dsc_url, source, diststr, version, comments=None, options=None, allow_
                                  stdout=out).check()
 
         # Sign and upload
-        util.daemon().gnupg.sign(changes_file_path)
-        changes.Base(changes_file_path).upload(util.daemon().model.mbd_get_ftp_endpoint(), force=True)
+        daemon.get().gnupg.sign(changes_file_path)
+        changes.Base(changes_file_path).upload(daemon.get_model().mbd_get_ftp_endpoint(), force=True)
         return {"dsc_url": dsc_url, "source": source, "distribution": diststr, "version": version}
 
 
@@ -368,7 +368,7 @@ def port(source, from_diststr, to_diststr, version=None, options=None):
         to_version = v.gen_internal_port(from_repository.mbd_get_mandatory_version_regex(from_distribution, from_suite),
                                          to_repository.mbd_get_default_version(to_distribution, to_suite))
 
-    return _port(config.URIS["repositories"]["static"].url_join(from_repository.mbd_dsc_pool_path(source, version)),
+    return _port(config.URIS["repositories"]["static"].url_join(from_repository.mbd_reprepro.pool.dsc_path(source, version)),
                  source,
                  to_diststr,
                  to_version,
