@@ -1,13 +1,6 @@
 """
 Run reprepro commands
 
-.. error:: **reprepro** (bookworm): Sometimes hangs on keyring package in testsuite (blocking all) (:debbug:`1056380`)
-
-  Reproduce: ``./devel profile _all updatetestall``.
-
-  This was introduced with the fix for (:debbug:`1050321`) in ``5.3.1-1+deb12u1``. Unfortunately, this
-  version is still [Apr 2024] in stable/bookworm. Fixed for trixie+.
-
 .. attention:: **reprepro**: Fails with ``debian/`` being a symlink in Debian native packages (:debbug:`768046`)
 
   In such a case, builds will be fine, but reprepro will not be able to install the package; you will only be able to
@@ -56,7 +49,7 @@ import threading
 
 import debian.debian_support
 
-from mini_buildd import call, changes, config, dist, util
+from mini_buildd import call, changes, config, dist, events, pool, util
 
 LOG = logging.getLogger(__name__)
 
@@ -115,11 +108,16 @@ class Ls(dict):
             repository, distribution, suite = util.models().parse_diststr(diststr)
 
             if ls.get("version") is not None:
-                ls["dsc_path"] = repository.mbd_dsc_pool_path(self.source, ls["version"], raise_exception=False)
+                ls["dsc_path"] = repository.mbd_reprepro.pool.dsc_path(self.source, ls["version"], raise_exception=False)
 
-                # Add changes files for convenience only - you can get to the changes files via 'events for this version' link
-                events_path = config.ROUTES["events"].path
-                ls["changes_paths"] = [events_path.removeprefix(p) for p in glob.glob(events_path.join(self.source, ls.get("version"), "**", "*_source.changes"), recursive=True)]
+                # Add INSTALLED event and changes paths from events directory for convenience
+                try:
+                    events_dir = config.ROUTES["events"].path
+                    event_paths = glob.glob(events_dir.join(self.source, ls.get("version"), "**", "*_INSTALLED.json"), recursive=True)
+                    ls["event_path"] = events_dir.removeprefix(event_paths[0])
+                    ls["changes_path"] = events.Event.load(event_paths[0]).extra.get("changes")
+                except Exception as e:
+                    util.log_exception(LOG, f"{self.source}-{ls.get('version')}: Can't get extra data from event dir for package in repository (maybe expired)", e)
 
             ls["uploadable"] = suite.uploadable
             if suite.migrates_to:
@@ -131,7 +129,7 @@ class Ls(dict):
             for rollback_diststr in ls["rollbacks"]:
                 rollback_ls = ls["rollbacks"][rollback_diststr]
                 if rollback_ls.get("version") is not None:
-                    rollback_ls["dsc_path"] = repository.mbd_dsc_pool_path(self.source, rollback_ls["version"], raise_exception=False)
+                    rollback_ls["dsc_path"] = repository.mbd_reprepro.pool.dsc_path(self.source, rollback_ls["version"], raise_exception=False)
 
     def rollbacks(self, diststr=None):
         result = {}
@@ -207,12 +205,13 @@ class Reprepro():
         self._basedir = basedir
         self._cmd = ["reprepro", "--verbose", "--waitforlock", "10", "--ignore", "unusedarch", "--basedir", f"{basedir}"]
         self._lock = _LOCKS.setdefault(self._basedir, threading.Lock())
+        self.pool = pool.Dir(basedir)
 
     def __str__(self):
         return f"Reprepro repository at {self._basedir}"
 
     def _call(self, args):
-        return call.Call(self._cmd + args).check().log().stdout
+        return call.Call(self._cmd + args).check(public_message="reprepro failed (see service log for details)").log().stdout
 
     def _call_locked(self, args):
         with self._lock:
@@ -270,6 +269,11 @@ class Reprepro():
             # Finally, rebuild all exportable indices
             self._call(["export"])
 
+            # Make arch=all packages available for potentially newly added architectectures (compare https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=926233)
+            for dist_str in os.listdir(dists_dir):
+                LOG.debug("Flood %s", dist_str)
+                self._call(["flood", dist_str])
+
     def check(self):
         return self._call_locked(["check"])
 
