@@ -1,4 +1,5 @@
 """mini-buildd's web application"""
+import io
 import logging
 import os
 import random
@@ -17,39 +18,49 @@ def get(*args, **kwargs):
     return django.core.handlers.wsgi.WSGIHandler(*args, **kwargs)
 
 
-def call(*args, **kwargs):
-    return django.core.management.call_command(*args, **kwargs, verbosity=2 if LOG.isEnabledFor(logging.DEBUG) else 0)
+class Call:
+    """Run ``django-admin`` commands with error handling and smart logging"""
+
+    def _log(self, log, msg):
+        log("[django-admin %s] %s", self.name, msg)
+
+    def _logf(self, log, f):
+        f.seek(0)
+        for line in f:
+            self._log(log, line.strip())
+
+    def __init__(self, name, *args, **kwargs):
+        self.name = name
+        self.error = None
+        self.stdout, self.stderr = io.StringIO(), io.StringIO()
+
+        try:
+            django.core.management.call_command(self.name, *args, **kwargs, stdout=self.stdout, stderr=self.stderr)
+        except BaseException as e:
+            self.error = e
+            raise
+        finally:
+            self._logf(LOG.info, self.stdout)
+            self._logf(LOG.warning, self.stderr)
+            if self.error is not None:
+                self._log(LOG.error, str(self.error))
 
 
 def migrate():
-    LOG.info("webapp: Migrating database...")
     try:
-        call("migrate", interactive=False, run_syncdb=True)
-    except django.db.OperationalError as e:
-        LOG.info("Error on database migration (%s) -- maybe initial. Retrying with '--fake-initial'...", e)
-        call("migrate", interactive=False, run_syncdb=True, fake_initial=True)
-
-
-def check():
-    LOG.info("webapp: Checking project...")
-    call("check")
-
-
-def diffsettings():
-    # For temporary debugging/check settings only
-    LOG.info("webapp: Showing settings diff to installed django...")
-    LOG.info(call("diffsettings", output="unified"))
-
-
-def fix_sqlite_path():
-    LOG.info("webapp: Fixing sqlite path...")
-    config.SqlitePath().fix_perms()
+        Call("migrate", interactive=False, run_syncdb=True)
+    except django.db.OperationalError:
+        LOG.info("Retrying migration with '--fake-initial'...")
+        Call("migrate", interactive=False, run_syncdb=True, fake_initial=True)
 
 
 def init():
     migrate()
-    check()
-    fix_sqlite_path()
+    Call("check")
+    config.SqlitePath().fix_perms()
+
+    # For temporary debugging/check settings only
+    # Call("diffsettings", output="unified")
 
 
 def set_admin_password(password):
@@ -60,7 +71,7 @@ def set_admin_password(password):
     :type password: string
     """
     # This import needs the django app to be already configured (since django 1.5.2)
-    from django.contrib.auth import models
+    from django.contrib.auth import models  # pylint: disable=import-outside-toplevel
 
     try:
         user = models.User.objects.get(username="admin")
@@ -82,12 +93,12 @@ def remove_system_artifacts():
 
 
 def loaddata(file_name):
-    call("loaddata", file_name)
+    Call("loaddata", file_name)
 
 
 def dumpdata(app_path):
     LOG.debug("Dumping data for: %s", app_path)
-    call("dumpdata", app_path, indent=2, format="json")
+    Call("dumpdata", app_path, indent=2, format="json")
 
 
 # Formerly in django_settings.py
@@ -214,6 +225,8 @@ def configure(smtp_string):
         STATIC_URL=config.URIS["static"]["static"].uri,
         ACCOUNT_ACTIVATION_DAYS=3,
         LOGIN_URL=config.URIS["accounts"]["login"].uri,
+        LOGOUT_REDIRECT_URL="/",
+        LOGIN_REDIRECT_URL="/",
 
         MIDDLEWARE=[
             "django.middleware.common.CommonMiddleware",
@@ -249,6 +262,12 @@ def configure(smtp_string):
                     ],
                 },
             },
+            # {
+            #     "BACKEND": "django.template.backends.jinja2.Jinja2",
+            #     "DIRS": [
+            #         f"{config.PY_PACKAGE_PATH}/mini_buildd/jinja2",
+            #     ],
+            # },
         ])
 
     django.setup()
